# Agent & Prompt Audit Log

Audit of `.agent.md` and `.prompt.md` files for all `agdt-*` and `speckit-*` CLI workflows.

---

## Summary

- **New agents created**: 98
- **New prompts created**: 96
- **Existing agents verified**: 16
- **Existing prompts verified**: 18
- **Total agents**: 114
- **Total prompts**: 114

---

## New Agent Files Created

| File | Category |
|------|----------|
| `.github/agents/agdt.add-jira-comment.agent.md` | Jira |
| `.github/agents/agdt.add-pull-request-comment.agent.md` | Azure DevOps |
| `.github/agents/agdt.add-users-to-project-role-batch.agent.md` | Jira |
| `.github/agents/agdt.add-users-to-project-role.agent.md` | Jira |
| `.github/agents/agdt.advance-workflow.agent.md` | Workflow Management |
| `.github/agents/agdt.approve-file.agent.md` | Azure DevOps |
| `.github/agents/agdt.approve-pull-request.agent.md` | Azure DevOps |
| `.github/agents/agdt.azure-context-current.agent.md` | Azure Context |
| `.github/agents/agdt.azure-context-ensure-login.agent.md` | Azure Context |
| `.github/agents/agdt.azure-context-status.agent.md` | Azure Context |
| `.github/agents/agdt.azure-context-use.agent.md` | Azure Context |
| `.github/agents/agdt.break-down-issue-into-subtasks.initiate.agent.md` | Jira |
| `.github/agents/agdt.check-user-exists.agent.md` | Jira |
| `.github/agents/agdt.check-users-exist.agent.md` | Jira |
| `.github/agents/agdt.clear-workflow.agent.md` | Workflow Management |
| `.github/agents/agdt.clear.agent.md` | Other |
| `.github/agents/agdt.confirm-suggestion-addressed.agent.md` | Azure DevOps |
| `.github/agents/agdt.copilot-auto-start.agent.md` | Setup |
| `.github/agents/agdt.create-agdt-bug-issue.agent.md` | GitHub |
| `.github/agents/agdt.create-agdt-documentation-issue.agent.md` | GitHub |
| `.github/agents/agdt.create-agdt-feature-issue.agent.md` | GitHub |
| `.github/agents/agdt.create-agdt-issue.agent.md` | GitHub |
| `.github/agents/agdt.create-agdt-task-issue.agent.md` | Tasks |
| `.github/agents/agdt.create-checklist.agent.md` | Workflow Management |
| `.github/agents/agdt.create-epic.agent.md` | Jira |
| `.github/agents/agdt.create-issue.agent.md` | Jira |
| `.github/agents/agdt.create-pipeline.agent.md` | Azure DevOps |
| `.github/agents/agdt.create-pull-request.agent.md` | Azure DevOps |
| `.github/agents/agdt.create-subtask.agent.md` | Jira |
| `.github/agents/agdt.delete.agent.md` | State Management |
| `.github/agents/agdt.find-role-id-by-name.agent.md` | Jira |
| `.github/agents/agdt.get-jira-issue.agent.md` | Jira |
| `.github/agents/agdt.get-next-workflow-prompt.agent.md` | Workflow Management |
| `.github/agents/agdt.get-pipeline-id.agent.md` | Azure DevOps |
| `.github/agents/agdt.get-project-role-details.agent.md` | Jira |
| `.github/agents/agdt.get-pull-request-details.agent.md` | Azure DevOps |
| `.github/agents/agdt.get-pull-request-threads.agent.md` | Azure DevOps |
| `.github/agents/agdt.get-run-details.agent.md` | Azure DevOps |
| `.github/agents/agdt.get-workflow.agent.md` | Workflow Management |
| `.github/agents/agdt.get.agent.md` | Other |
| `.github/agents/agdt.git-force-push.agent.md` | Git |
| `.github/agents/agdt.git-publish.agent.md` | Git |
| `.github/agents/agdt.git-push.agent.md` | Git |
| `.github/agents/agdt.git-save-work.agent.md` | Git |
| `.github/agents/agdt.git-stage.agent.md` | Git |
| `.github/agents/agdt.git-sync.agent.md` | Git |
| `.github/agents/agdt.list-pipelines.agent.md` | Azure DevOps |
| `.github/agents/agdt.list-project-roles.agent.md` | Jira |
| `.github/agents/agdt.mark-file-reviewed.agent.md` | Azure DevOps |
| `.github/agents/agdt.mark-pull-request-draft.agent.md` | Azure DevOps |
| `.github/agents/agdt.network-status.agent.md` | Network/VPN |
| `.github/agents/agdt.optimize-issue-for-ai-agent.initiate.agent.md` | Workflow Initiation |
| `.github/agents/agdt.parse-jira-error-report.agent.md` | Jira |
| `.github/agents/agdt.publish-pull-request.agent.md` | Azure DevOps |
| `.github/agents/agdt.query-app-insights.agent.md` | Azure CLI |
| `.github/agents/agdt.query-fabric-dap-errors.agent.md` | Azure CLI |
| `.github/agents/agdt.query-fabric-dap-provisioning.agent.md` | Azure CLI |
| `.github/agents/agdt.query-fabric-dap-timeline.agent.md` | Azure CLI |
| `.github/agents/agdt.reject-suggestion-resolution.agent.md` | Azure DevOps |
| `.github/agents/agdt.release-pypi.agent.md` | Release |
| `.github/agents/agdt.reply-to-pull-request-thread.agent.md` | Azure DevOps |
| `.github/agents/agdt.request-changes-with-suggestion.agent.md` | Azure DevOps |
| `.github/agents/agdt.request-changes.agent.md` | Azure DevOps |
| `.github/agents/agdt.resolve-merge-conflicts.agent.md` | Git |
| `.github/agents/agdt.resolve-thread.agent.md` | Azure DevOps |
| `.github/agents/agdt.review.agent.md` | Review |
| `.github/agents/agdt.run-e2e-tests-fabric.agent.md` | Azure DevOps |
| `.github/agents/agdt.run-e2e-tests-synapse.agent.md` | Azure DevOps |
| `.github/agents/agdt.run-wb-patch.agent.md` | Azure DevOps |
| `.github/agents/agdt.set.agent.md` | State Management |
| `.github/agents/agdt.setup-certs.agent.md` | Setup |
| `.github/agents/agdt.setup-check.agent.md` | Setup |
| `.github/agents/agdt.setup-copilot-cli.agent.md` | Setup |
| `.github/agents/agdt.setup-gh-cli.agent.md` | Setup |
| `.github/agents/agdt.setup-worktree-background.agent.md` | Setup |
| `.github/agents/agdt.setup.agent.md` | Setup |
| `.github/agents/agdt.show-checklist.agent.md` | Workflow Management |
| `.github/agents/agdt.show-other-incomplete-tasks.agent.md` | Tasks |
| `.github/agents/agdt.show.agent.md` | Other |
| `.github/agents/agdt.squash-commits.agent.md` | Git |
| `.github/agents/agdt.submit-file-review.agent.md` | Azure DevOps |
| `.github/agents/agdt.task-log.agent.md` | Tasks |
| `.github/agents/agdt.task-status.agent.md` | Tasks |
| `.github/agents/agdt.task-wait.agent.md` | Tasks |
| `.github/agents/agdt.tasks-clean.agent.md` | Tasks |
| `.github/agents/agdt.tasks.agent.md` | Tasks |
| `.github/agents/agdt.test-file.agent.md` | Testing |
| `.github/agents/agdt.test-pattern.agent.md` | Testing |
| `.github/agents/agdt.test-quick.agent.md` | Testing |
| `.github/agents/agdt.test.agent.md` | Testing |
| `.github/agents/agdt.update-checklist.agent.md` | Workflow Management |
| `.github/agents/agdt.update-jira-issue.agent.md` | Jira |
| `.github/agents/agdt.update-pipeline.agent.md` | Azure DevOps |
| `.github/agents/agdt.vpn-off.agent.md` | Network/VPN |
| `.github/agents/agdt.vpn-on.agent.md` | Network/VPN |
| `.github/agents/agdt.vpn-run.agent.md` | Network/VPN |
| `.github/agents/agdt.vpn-status.agent.md` | Network/VPN |
| `.github/agents/agdt.wait-for-run.agent.md` | Azure DevOps |

---

## New Prompt Files Created

| File |
|------|
| `.github/prompts/agdt.add-jira-comment.prompt.md` |
| `.github/prompts/agdt.add-pull-request-comment.prompt.md` |
| `.github/prompts/agdt.add-users-to-project-role-batch.prompt.md` |
| `.github/prompts/agdt.add-users-to-project-role.prompt.md` |
| `.github/prompts/agdt.advance-workflow.prompt.md` |
| `.github/prompts/agdt.approve-file.prompt.md` |
| `.github/prompts/agdt.approve-pull-request.prompt.md` |
| `.github/prompts/agdt.azure-context-current.prompt.md` |
| `.github/prompts/agdt.azure-context-ensure-login.prompt.md` |
| `.github/prompts/agdt.azure-context-status.prompt.md` |
| `.github/prompts/agdt.azure-context-use.prompt.md` |
| `.github/prompts/agdt.break-down-issue-into-subtasks.initiate.prompt.md` |
| `.github/prompts/agdt.check-user-exists.prompt.md` |
| `.github/prompts/agdt.check-users-exist.prompt.md` |
| `.github/prompts/agdt.clear-workflow.prompt.md` |
| `.github/prompts/agdt.clear.prompt.md` |
| `.github/prompts/agdt.confirm-suggestion-addressed.prompt.md` |
| `.github/prompts/agdt.copilot-auto-start.prompt.md` |
| `.github/prompts/agdt.create-agdt-bug-issue.prompt.md` |
| `.github/prompts/agdt.create-agdt-documentation-issue.prompt.md` |
| `.github/prompts/agdt.create-agdt-feature-issue.prompt.md` |
| `.github/prompts/agdt.create-agdt-issue.prompt.md` |
| `.github/prompts/agdt.create-agdt-task-issue.prompt.md` |
| `.github/prompts/agdt.create-checklist.prompt.md` |
| `.github/prompts/agdt.create-epic.prompt.md` |
| `.github/prompts/agdt.create-issue.prompt.md` |
| `.github/prompts/agdt.create-pipeline.prompt.md` |
| `.github/prompts/agdt.create-pull-request.prompt.md` |
| `.github/prompts/agdt.create-subtask.prompt.md` |
| `.github/prompts/agdt.delete.prompt.md` |
| `.github/prompts/agdt.find-role-id-by-name.prompt.md` |
| `.github/prompts/agdt.get-jira-issue.prompt.md` |
| `.github/prompts/agdt.get-next-workflow-prompt.prompt.md` |
| `.github/prompts/agdt.get-pipeline-id.prompt.md` |
| `.github/prompts/agdt.get-project-role-details.prompt.md` |
| `.github/prompts/agdt.get-pull-request-details.prompt.md` |
| `.github/prompts/agdt.get-pull-request-threads.prompt.md` |
| `.github/prompts/agdt.get-run-details.prompt.md` |
| `.github/prompts/agdt.get-workflow.prompt.md` |
| `.github/prompts/agdt.get.prompt.md` |
| `.github/prompts/agdt.git-force-push.prompt.md` |
| `.github/prompts/agdt.git-publish.prompt.md` |
| `.github/prompts/agdt.git-push.prompt.md` |
| `.github/prompts/agdt.git-save-work.prompt.md` |
| `.github/prompts/agdt.git-stage.prompt.md` |
| `.github/prompts/agdt.git-sync.prompt.md` |
| `.github/prompts/agdt.list-pipelines.prompt.md` |
| `.github/prompts/agdt.list-project-roles.prompt.md` |
| `.github/prompts/agdt.mark-file-reviewed.prompt.md` |
| `.github/prompts/agdt.mark-pull-request-draft.prompt.md` |
| `.github/prompts/agdt.network-status.prompt.md` |
| `.github/prompts/agdt.optimize-issue-for-ai-agent.initiate.prompt.md` |
| `.github/prompts/agdt.parse-jira-error-report.prompt.md` |
| `.github/prompts/agdt.publish-pull-request.prompt.md` |
| `.github/prompts/agdt.query-app-insights.prompt.md` |
| `.github/prompts/agdt.query-fabric-dap-errors.prompt.md` |
| `.github/prompts/agdt.query-fabric-dap-provisioning.prompt.md` |
| `.github/prompts/agdt.query-fabric-dap-timeline.prompt.md` |
| `.github/prompts/agdt.reject-suggestion-resolution.prompt.md` |
| `.github/prompts/agdt.release-pypi.prompt.md` |
| `.github/prompts/agdt.reply-to-pull-request-thread.prompt.md` |
| `.github/prompts/agdt.request-changes-with-suggestion.prompt.md` |
| `.github/prompts/agdt.request-changes.prompt.md` |
| `.github/prompts/agdt.resolve-thread.prompt.md` |
| `.github/prompts/agdt.review.prompt.md` |
| `.github/prompts/agdt.run-e2e-tests-fabric.prompt.md` |
| `.github/prompts/agdt.run-e2e-tests-synapse.prompt.md` |
| `.github/prompts/agdt.run-wb-patch.prompt.md` |
| `.github/prompts/agdt.set.prompt.md` |
| `.github/prompts/agdt.setup-certs.prompt.md` |
| `.github/prompts/agdt.setup-check.prompt.md` |
| `.github/prompts/agdt.setup-copilot-cli.prompt.md` |
| `.github/prompts/agdt.setup-gh-cli.prompt.md` |
| `.github/prompts/agdt.setup-worktree-background.prompt.md` |
| `.github/prompts/agdt.setup.prompt.md` |
| `.github/prompts/agdt.show-checklist.prompt.md` |
| `.github/prompts/agdt.show-other-incomplete-tasks.prompt.md` |
| `.github/prompts/agdt.show.prompt.md` |
| `.github/prompts/agdt.submit-file-review.prompt.md` |
| `.github/prompts/agdt.task-log.prompt.md` |
| `.github/prompts/agdt.task-status.prompt.md` |
| `.github/prompts/agdt.task-wait.prompt.md` |
| `.github/prompts/agdt.tasks-clean.prompt.md` |
| `.github/prompts/agdt.tasks.prompt.md` |
| `.github/prompts/agdt.test-file.prompt.md` |
| `.github/prompts/agdt.test-pattern.prompt.md` |
| `.github/prompts/agdt.test-quick.prompt.md` |
| `.github/prompts/agdt.test.prompt.md` |
| `.github/prompts/agdt.update-checklist.prompt.md` |
| `.github/prompts/agdt.update-jira-issue.prompt.md` |
| `.github/prompts/agdt.update-pipeline.prompt.md` |
| `.github/prompts/agdt.vpn-off.prompt.md` |
| `.github/prompts/agdt.vpn-on.prompt.md` |
| `.github/prompts/agdt.vpn-run.prompt.md` |
| `.github/prompts/agdt.vpn-status.prompt.md` |
| `.github/prompts/agdt.wait-for-run.prompt.md` |

---

## Existing Agents Verified (No Changes Needed)

| File |
|------|
| `.github/agents/agdt.apply-pr-suggestions.initiate.agent.md` |
| `.github/agents/agdt.create-jira-epic.initiate.agent.md` |
| `.github/agents/agdt.create-jira-issue.initiate.agent.md` |
| `.github/agents/agdt.create-jira-subtask.initiate.agent.md` |
| `.github/agents/agdt.pull-request-review.initiate.agent.md` |
| `.github/agents/agdt.update-jira-issue.initiate.agent.md` |
| `.github/agents/agdt.work-on-jira-issue.initiate.agent.md` |
| `.github/agents/speckit.analyze.agent.md` |
| `.github/agents/speckit.checklist.agent.md` |
| `.github/agents/speckit.clarify.agent.md` |
| `.github/agents/speckit.constitution.agent.md` |
| `.github/agents/speckit.implement.agent.md` |
| `.github/agents/speckit.plan.agent.md` |
| `.github/agents/speckit.specify.agent.md` |
| `.github/agents/speckit.tasks.agent.md` |
| `.github/agents/speckit.taskstoissues.agent.md` |

---

## Existing Prompts Verified (No Changes Needed)

| File |
|------|
| `.github/prompts/agdt.apply-pr-suggestions.initiate.prompt.md` |
| `.github/prompts/agdt.create-jira-epic.initiate.prompt.md` |
| `.github/prompts/agdt.create-jira-issue.initiate.prompt.md` |
| `.github/prompts/agdt.create-jira-subtask.initiate.prompt.md` |
| `.github/prompts/agdt.pull-request-review.initiate.prompt.md` |
| `.github/prompts/agdt.resolve-merge-conflicts.prompt.md` |
| `.github/prompts/agdt.squash-commits.prompt.md` |
| `.github/prompts/agdt.update-jira-issue.initiate.prompt.md` |
| `.github/prompts/agdt.work-on-jira-issue.initiate.prompt.md` |
| `.github/prompts/speckit.analyze.prompt.md` |
| `.github/prompts/speckit.checklist.prompt.md` |
| `.github/prompts/speckit.clarify.prompt.md` |
| `.github/prompts/speckit.constitution.prompt.md` |
| `.github/prompts/speckit.implement.prompt.md` |
| `.github/prompts/speckit.plan.prompt.md` |
| `.github/prompts/speckit.specify.prompt.md` |
| `.github/prompts/speckit.tasks.prompt.md` |
| `.github/prompts/speckit.taskstoissues.prompt.md` |

---

## Documentation Updated

| File | Change |
|------|--------|
| `docs/copilot-commands.md` | Added complete inventory of all CLI command agents organized by category |
| `README.md` | Updated Copilot Commands section to reference individual CLI command agents |

---

## Deprecated/Orphaned Files

No deprecated or orphaned agent/prompt files were found. All existing files
correspond to active CLI commands or workflow steps.
